netapp_ontap.models.zapp_nvme_components_tiering API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.zapp_nvme_components_tiering`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ZappNvmeComponentsTieringSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ZappNvmeComponentsTiering object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `control POST`

    Storage tiering placement rules for the container(s)

    Valid choices:

    - required
    - best_effort
    - disallowed
  `object_stores POST`

    The object_stores field of the zapp_nvme_components_tiering.

  `policy GET POST`

    The storage tiering type of the application component.

    Valid choices:

    - all
    - auto
    - none
    - snapshot_only